==> asset_management-0.0.1.gem: app/models/asset_management/asset_data.rb <==
# encoding: UTF-8

require 'rmagick'

include Magick

module AssetManagement
  class AssetData < ActiveRecord::Base
    self.table_name = 'asset_management_asset_data'

    belongs_to :folder, :class_name => '::AssetManagement::VirtualFolder'

    #accepts_nested_attributes_for :folder #, :reject_if => lambda { |a| a[:name].blank? }, :allow_destroy => true
    #attr_accessible :folder, :folder_attributes

    #acts_as_taggable

    attr_accessible :name
    attr_accessible :filename
    attr_accessible :data
    attr_accessible :mime_type
    attr_accessible :size
    attr_accessible :description
    attr_accessible :folder, :folder_id
    attr_accessible :storage_reference
    attr_accessible :asset_file

    validates :filename, :presence => true
    validates :data, :presence => true
    validates :size, :presence => true
    validates :mime_type, :presence => true
    #validates :folder, :presence => true

    #validates_format_of :mime_type, :with => /^image/, :message => "Only images are currently supported"

    #----------------------------------------------------------------------------

    before_save { |record| record.name = record.filename if record.name.blank? }

    #----------------------------------------------------------------------------

    def folder_name
      folder.nil? ? '-NONE-' : folder.name
    end

    def to_s
      name
    end

    #----------------------------------------------------------------------------

    def asset_file=(uploaded_data)
      return if uploaded_data.blank?
      self.filename  = uploaded_data.original_filename.chomp
      self.data      = uploaded_data.read
      self.size      = uploaded_data.size
      self.mime_type = uploaded_data.content_type.chomp
    end

    def image_dimensions
      result = ''
      if self.mime_type =~ /^image/
        image = self.load_magick_image
        result = "#{image.columns}x#{image.rows}"
      end
      result
    end

    def load_magick_image
      begin
        if self.mime_type =~ /(vnd.microsoft.icon|x-icon)/
          (Magick::Image::from_blob(self.data){ self.format = "ico" }).first
        elsif self.mime_type =~ /^image/
          Magick::Image::from_blob(self.data).first
        else
          mime_file = self.mime_type.gsub(/\//, "-") + '.png'
          mime_file_path = File.join(::AssetManagement::Engine.root, 'app', 'assets', 'images', 'asset_management', 'mimetype-icons', 'oxygen', mime_file)

          unless File.exists?(mime_file_path)
            mime_type_prefix = self.mime_type.slice(0..(self.mime_type.index('/')-1))
            mime_file = mime_type_prefix + '-x-generic.png'
            mime_file_path = File.join(::AssetManagement::Engine.root, 'app', 'assets', 'images', 'asset_management', 'mimetype-icons', 'oxygen', mime_file)
          end

          Magick::Image::read(mime_file_path).first
        end
      rescue Magick::ImageMagickError
        logger.error "ERROR: #{$!}\n"
        logger.error "#{$0}: ImageMagickError - #{$!}\n"
      end
    end

  end
end

==> asset_management-0.1.2.gem: app/models/asset_management/asset_data.rb <==
# encoding: UTF-8

require 'rmagick'

include Magick

module AssetManagement
  class AssetData < ActiveRecord::Base
    self.table_name = 'asset_management_asset_data'

    belongs_to :folder, :class_name => '::AssetManagement::VirtualFolder'

    #accepts_nested_attributes_for :folder #, :reject_if => lambda { |a| a[:name].blank? }, :allow_destroy => true
    #attr_accessible :folder, :folder_attributes

    #acts_as_taggable

    # attr_accessible :name
    # attr_accessible :filename
    # attr_accessible :data
    # attr_accessible :mime_type
    # attr_accessible :size
    # attr_accessible :description
    # attr_accessible :folder, :folder_id
    # attr_accessible :storage_reference
    # attr_accessible :asset_file

    validates :filename, :presence => true
    validates :data, :presence => true
    validates :size, :presence => true
    validates :mime_type, :presence => true
    #validates :folder, :presence => true

    #validates_format_of :mime_type, :with => /^image/, :message => "Only images are currently supported"

    #----------------------------------------------------------------------------

    before_save { |record| record.name = record.filename if record.name.blank? }

    #----------------------------------------------------------------------------

    def folder_name
      folder.nil? ? '-NONE-' : folder.name
    end

    def to_s
      name
    end

    #----------------------------------------------------------------------------

    def asset_file=(uploaded_data)
      return if uploaded_data.blank?
      self.filename  = uploaded_data.original_filename.chomp
      self.data      = uploaded_data.read
      self.size      = uploaded_data.size
      self.mime_type = uploaded_data.content_type.chomp
    end

    def image_dimensions
      result = ''
      if self.mime_type =~ /^image/
        image = self.load_magick_image
        result = "#{image.columns}x#{image.rows}"
      end
      result
    end

    def load_magick_image
      begin
        if self.mime_type =~ /(vnd.microsoft.icon|x-icon)/
          (Magick::Image::from_blob(self.data){ self.format = "ico" }).first
        elsif self.mime_type =~ /^image/
          Magick::Image::from_blob(self.data).first
        else
          mime_file = self.mime_type.gsub(/\//, "-") + '.png'
          mime_file_path = File.join(::AssetManagement::Engine.root, 'app', 'assets', 'images', 'asset_management', 'mimetype-icons', 'oxygen', mime_file)

          unless File.exists?(mime_file_path)
            mime_type_prefix = self.mime_type.slice(0..(self.mime_type.index('/')-1))
            mime_file = mime_type_prefix + '-x-generic.png'
            mime_file_path = File.join(::AssetManagement::Engine.root, 'app', 'assets', 'images', 'asset_management', 'mimetype-icons', 'oxygen', mime_file)
          end

          Magick::Image::read(mime_file_path).first
        end
      rescue Magick::ImageMagickError
        logger.error "ERROR: #{$!}\n"
        logger.error "#{$0}: ImageMagickError - #{$!}\n"
      end
    end

  end
end
